@@ -1,4 +1,5 @@
 import concurrent.futures
+import math
 import os
 import queue
 import time
@@ -381,38 +382,20 @@ def remove_tile_edge_junctions(
     stream_endpoints = np.array(stream_endpoints, dtype=np.float64)  # type: ignore[assignment]
 
     # Get lists of what needs to be merged/deleted
-    progress_callback(
-        phase="Finding streams to merge",
-        step=1,
-        total_steps=3,
-        progress=0.33,
-        message="Analyzing stream connections",
-    )
     junction_fids_to_remove, stream_pairs_to_merge, new_endpoints = (
         find_streams_to_merge(
             junction_points, junction_fids, stream_endpoints, geotransform
         )
     )
 
-    # Process the results with GDAL
-    total = len(junction_fids_to_remove)
-
     # Keep track of stream replacements
     stream_replacements: dict[int, int] = {}  # old_fid -> new_fid
+    total_merges = len(stream_pairs_to_merge)
 
     for i, (
         (fid1, fid2, merge_type),
         (_up_x, _up_y, _down_x, _down_y),
     ) in enumerate(zip(stream_pairs_to_merge, new_endpoints), 1):
-        # Report progress
-        progress_callback(
-            phase="Merging streams",
-            step=i,
-            total_steps=total,
-            progress=(i / total) * 0.33 + 0.33,
-            message=f"Merging stream {i}/{total}",
-        )
-
         # Get current FIDs accounting for previous merges
         current_fid1 = stream_replacements.get(fid1, fid1)
         current_fid2 = stream_replacements.get(fid2, fid2)
@@ -455,15 +438,12 @@ def remove_tile_edge_junctions(
         stream2 = None
         new_feature = None
 
+        # Report progress
+        if i % 100 == 0 or i == total_merges:
+            progress_callback(message=f"Merged {i}/{total_merges} segments")
+
     # Remove junctions
-    for i, junction_fid in enumerate(junction_fids_to_remove, 1):
-        progress_callback(
-            phase="Removing junctions",
-            step=i,
-            total_steps=total,
-            progress=(i / total) * 0.33 + 0.67,
-            message=f"Removing junction {i}/{total}",
-        )
+    for junction_fid in junction_fids_to_remove:
         junctions_layer.DeleteFeature(junction_fid)  # type: ignore[attr-defined]
 
     # Cleanup
@@ -559,14 +539,20 @@ def extract_streams_tiled(
             # Write lines
             write_lines(lines_layer, lines)
             task_queue.get()
+            # Report progress as tiles complete
+            chunk_counter[0] += 1
+            tracker.callback(message=f"Chunk {chunk_counter[0]}/{total_chunks}")
 
-    tracker.update(1, "Extracting stream networks from tiles")
+    chunk_counter = [0]  # Use list for mutability in closure
+    total_chunks = math.ceil(fac_band.YSize / chunk_size) * math.ceil(
+        fac_band.XSize / chunk_size
+    )
+
+    tracker.update(1, "Extract streams")
 
     # Process tiles in parallel
     with concurrent.futures.ThreadPoolExecutor(max_workers=max_workers) as executor:
-        for fac_tile in raster_chunker(
-            fac_band, chunk_size, progress_callback=progress_callback
-        ):
+        for fac_tile in raster_chunker(fac_band, chunk_size):
             while task_queue.full():
                 time.sleep(0.1)
             task_queue.put(0)
@@ -598,13 +584,13 @@ def extract_streams_tiled(
     fac_ds = None
     fdr_ds = None
 
-    tracker.update(2, "Merging stream segments across tiles")
+    tracker.update(2, "Merge segments")
 
     remove_tile_edge_junctions(
         geotransform, streams_dataset_path, progress_callback=progress_callback
     )
 
-    tracker.update(3, "Adding downstream junctions")
+    tracker.update(3, "Add junctions")
 
     add_downstream_junctions(
         geotransform, streams_dataset_path, progress_callback=progress_callback
