@@ -1,17 +1,17 @@
 """Timing and resource tracking utilities for overflow commands."""
 
 import os
+import sys
 import time
 from contextlib import contextmanager
 from pathlib import Path
 
-from rich.console import Console, Group
-from rich.panel import Panel
+from rich.console import Console
 from rich.progress import Progress, SpinnerColumn, TextColumn, TimeElapsedColumn
 from rich.table import Table
 from rich.text import Text
 
-console = Console(force_terminal=True)
+console = Console()
 
 
 class ResourceStats:
@@ -157,54 +157,64 @@ class ResourceStats:
 
         return table
 
-    def get_summary_panel(self, success: bool = True) -> Panel:
-        """Create a comprehensive summary panel.
+    def get_summary_panel(self, success: bool = True) -> Text:
+        """Create a simple summary output.
 
         Args:
             success: Whether the operation completed successfully
 
         Returns:
-            Rich Panel with complete summary
+            Rich Text with summary lines
         """
-        renderables: list = []
+        lines = []
+
+        # Add newline before summary for consistency
+        lines.append(Text(""))
 
         # Status
         if success:
-            renderables.append(
-                Text("✓ Operation completed successfully", style="bold green")
+            lines.append(
+                Text("✓ All operations completed successfully.", style="bold green")
             )
         else:
-            renderables.append(Text("✗ Operation failed", style="bold red"))
-        renderables.append(Text())
+            lines.append(Text("✗ Operation failed", style="bold red"))
 
         # Total time
         if "Total processing" in self.stats:
             total_duration = self.stats["Total processing"]
-            renderables.append(
-                Text.assemble(
-                    ("Total time: ", "bold yellow"),
-                    (self.format_compact_duration(total_duration), "cyan"),
+            lines.append(
+                Text(
+                    f"Total time: {self.format_compact_duration(total_duration)}",
+                    style="cyan",
                 )
             )
-            renderables.append(Text())
 
-        # Timing breakdown table
-        if self.stats:
-            timing_table = self.get_timing_table()
-            renderables.append(timing_table)
-            renderables.append(Text())
+        # Output files
+        if self.output_files:
+            lines.append(Text("\nOutputs:", style="bold"))
 
-        # Output files table
-        output_table = self.get_output_files_table()
-        if output_table:
-            renderables.append(output_table)
+            # Use same width as step names for consistency (34 chars)
+            max_name_length = 34
 
-        return Panel(
-            Group(*renderables),
-            title="[bold blue]Summary[/bold blue]",
-            border_style="blue",
-            padding=(1, 2),
-        )
+            for description, file_path in self.output_files:
+                if file_path.exists():
+                    size = os.path.getsize(file_path)
+                    # Pad filename to align sizes
+                    padded_name = file_path.name.ljust(max_name_length)
+                    lines.append(
+                        Text(
+                            f"  • {padded_name} {self.format_file_size(size)}",
+                            style="dim",
+                        )
+                    )
+                else:
+                    padded_name = file_path.name.ljust(max_name_length)
+                    lines.append(
+                        Text(f"  • {padded_name} (not found)", style="dim red")
+                    )
+
+        # Combine all lines
+        return Text("\n").join(lines)
 
 
 # Global resource stats instance
@@ -256,14 +266,20 @@ def timer(
     Example:
         >>> with timer("Processing data", spinner=True):
         ...     process_data()
-        ✓ Processing data completed in 2 minutes and 34 seconds
+        ✓ Processing data completed in 2s
     """
     start_time = time.time()
 
     if spinner and not silent:
+        # Custom spinner frames - single character
+        spinner_frames = ["■", "≡", "=", "-", "=", "≡"]
+        spinner_col = SpinnerColumn(spinner_name="dots", style="cyan")
+        # Override frames
+        spinner_col.spinner.frames = spinner_frames
+
         with Progress(
-            SpinnerColumn(),
-            TextColumn("[bold blue]{task.description}"),
+            spinner_col,
+            TextColumn("{task.description}"),
             TimeElapsedColumn(),
             console=console,
             transient=True,
@@ -276,13 +292,15 @@ def timer(
                 resource_stats.add_stats(description, duration)
                 progress.stop()
 
-                console.print(
-                    f"[green]✓[/green] {description} completed in "
-                    f"[bold cyan]{Timer.format_duration(duration)}[/bold cyan]"
-                )
+                if sys.stdout.isatty():
+                    console.print(
+                        f"[dim cyan]✓[/dim cyan] [white]Done[/white] "
+                        f"[dim]({ResourceStats.format_compact_duration(duration)})[/dim]"
+                    )
+                else:
+                    print(f"Done ({ResourceStats.format_compact_duration(duration)})")
     else:
-        if not silent:
-            console.print(f"[bold blue]{description}...[/bold blue]")
+        # Silent mode during execution - only show completion message
         try:
             yield
         finally:
@@ -290,7 +308,10 @@ def timer(
             resource_stats.add_stats(description, duration)
 
             if not silent:
-                console.print(
-                    f"[green]✓[/green] {description} completed in "
-                    f"[bold cyan]{Timer.format_duration(duration)}[/bold cyan]"
-                )
+                if sys.stdout.isatty():
+                    console.print(
+                        f"[dim cyan]✓[/dim cyan] [white]Done[/white] "
+                        f"[dim]({ResourceStats.format_compact_duration(duration)})[/dim]"
+                    )
+                else:
+                    print(f"Done ({ResourceStats.format_compact_duration(duration)})")
